--[[
Include file for debug functions
--]]

local debug = {}


-- Function debug.print_direction(dir)
--[[
Debug function to print directions    
--]]
function debug.print_direction(dir)
  if dir == defines.direction.north then return "North" end
  if dir == defines.direction.east  then return "East"  end
  if dir == defines.direction.south then return "South" end
  if dir == defines.direction.west  then return "West"  end
  return "<Undefined>"
end -- debug.print_direction(dir)




-- Function debug.error(message)
--[[
Debug function, writes error to log.
--]]
function debug.error(message)
  game.players[1].print("Error: " .. message)
  error(message)
end -- debug.error(message)




-- Function debug.info(message)
--[[
Simple print to console debug function.
--]]
function debug.info(message)
  game.players[1].print(message)
end -- debug.info(message)




-- Function debug.print_memory(memory)
--[[
Simple print to console debug function. Prints the memory structure.
--]]
function debug.print_memory(memory)
  if not memory.max or memory.max == 0 then return end

  for i = 1, memory.max do
    local line = i .. '/' .. memory.max .. ": "
    if memory[i] then
      line = line .. memory[i].name .. " " .. debug.format_position(memory[i].position)
      line = line .. " " .. debug.print_direction(memory[i].direction)
    else
      line = line .. "nil"
    end
    debug.info(line)  
  end
end -- debug.print_memory(memory)




-- Function debug.format_position(pos)
--[[
Returns a string formatted to display a position.
--]]
function debug.format_position(pos)
  return pos.x .. "/" .. pos.y
end -- debug.format_position(pos)






-- End module debug
return debug
