--[[
Include file for the playerstatus class functions
--]]

--[[
Each player has status variables related to the automatic belt rotation. The playerstatus module creates and destroys the applicable variables per player.
--]]


local playerstatus = {}




-- Function playerstatus.addplayer(index)
--[[
Add a new player 'index' to the list. All status variables are initialised and added to the array.
--]]   
function playerstatus.addplayer(index)
  
  -- If the player already exists, skip.
  if playerstatus[index] then return end

  -- Create and initialise variables for the new player.
  playerstatus[index] = {}
  local plr = playerstatus[index]

  ---- Variables:
  
  -- The player index 
  plr.index = index

  -- This contains a local copy of the entity data, for belts layed after each other.
  plr.prev_belt = {}
  plr.prev_belt.name = nil
  plr.prev_belt.type = nil
  plr.prev_belt.direction = nil
  plr.prev_belt.surface = { index = nil }
  plr.prev_belt.position = { x = nil , y = nil }

  plr.curr_belt = {}
  plr.curr_belt.name = nil
  plr.curr_belt.type = nil
  plr.curr_belt.direction = nil
  plr.curr_belt.surface = { index = nil }
  plr.curr_belt.position = { x = nil , y = nil }
  
--[[
  -- The belts layed after each other are stored in here.
  plr.prev_belt = nil
  plr.curr_belt = nil
--]]
   
  -- Remember the direction the belts were originally pointing when placed. 
  -- This helps detect manual belt turning by the player (hand-rotating).
  plr.prev_original_direction = nil
  plr.curr_original_direction = nil

  -- Remember the previous location a belt was removed by the player. It is used to
  -- determine if a placed belt is actually a belt placed over another belt but rotated.
  -- (overlay-rotating).
  plr.prev_belt_removed = {}
  plr.prev_belt_removed.surface = { index = nil }
  plr.prev_belt_removed.gametick = 0
  plr.prev_belt_removed.position = {x = nil, y = nil}
  
end -- playerstatus.addplayer(index)




-- Function playerstatus.removeplayer(index)
--[[
Remove a player 'index' from the list.
--]]   
function playerstatus.removeplayer(index)
  playerstatus[index] = nil
end -- playerstatus.removeplayer(index)




-- End module playerstatus
return playerstatus
